// ---------------------------------------------------------------------------
// @file       avrJtag.h
// @brief      JTAG commands for programming an AVR microcontroller 
// 
// @author     Laurent Saint-Marcel (lstmarcel@yahoo.fr)
// @date       2009/09/25
// ---------------------------------------------------------------------------

#ifndef __AVR_JTAG_H__
#define __AVR_JTAG_H__

#include <inttypes.h>

// ----------------------------------------------------------------------------
// Write 4 bits of 'instruction' in the IR register
// Initial state: TestLogicReset or RunTestIdle
// Final state:   RunTestIdle
// ----------------------------------------------------------------------------
void jtagWriteInstruction(uint8_t instruction);

// ----------------------------------------------------------------------------
// Write 'length' bits of 'cmd' in the DR register and return 'length' bits
// from DR
// Initial state: TestLogicReset or RunTestIdle
// Final state:   RunTestIdle
// ----------------------------------------------------------------------------
uint32_t jtagWriteData(uint32_t cmd, uint8_t length);

// ----------------------------------------------------------------------------
// Write 15 bits of 'cmd' in the DR register and return 15 bits from DR
// Initial state: TestLogicReset or RunTestIdle
// Final state:   RunTestIdle
// ----------------------------------------------------------------------------
uint16_t jtagWriteProgCmd(uint8_t cmdH, uint8_t cmdL);


// ----------------------------------------------------------------------------
// AVR jtag Entering Programming Mode
// ----------------------------------------------------------------------------
void jtagEnteringProgramming();

// ----------------------------------------------------------------------------
// AVR jtag Leaving Programming Mode
// ----------------------------------------------------------------------------
void jtagLeavingProgramming();


// ----------------------------------------------------------------------------
// AVR jtag return the 4 bytes of the device ID
// ----------------------------------------------------------------------------
uint32_t avrJtagGetDeviceId();

// ----------------------------------------------------------------------------
// AVR jtag Return the 3 bytes of the device signature ~= avrJtagGetDeviceId
// ----------------------------------------------------------------------------
uint32_t avrJtagReadSignature();

// ----------------------------------------------------------------------------
// AVR jtag Return the calibration byte
// ----------------------------------------------------------------------------
uint8_t avrJtagReadCalibration();

// ----------------------------------------------------------------------------
// AVR jtag Return the fuse Extented byte
// ----------------------------------------------------------------------------
uint8_t avrJtagReadFuseExt();

// ----------------------------------------------------------------------------
// AVR jtag Return the fuse High byte
// ----------------------------------------------------------------------------
uint8_t avrJtagReadFuseHigh();

// ----------------------------------------------------------------------------
// AVR jtag Return the fuse Low byte
// ----------------------------------------------------------------------------
uint8_t avrJtagReadFuseLow();

// ----------------------------------------------------------------------------
// AVR jtag Return the lock byte
// ----------------------------------------------------------------------------
uint8_t avrJtagReadLock();


// ----------------------------------------------------------------------------
// AVR jtag Write the fuse Extented byte
// ----------------------------------------------------------------------------
void avrJtagWriteFuseExt(uint8_t);

// ----------------------------------------------------------------------------
// AVR jtag Write the fuse High byte
// ----------------------------------------------------------------------------
void avrJtagWriteFuseHigh(uint8_t);

// ----------------------------------------------------------------------------
// AVR jtag Write the fuse Low byte
// ----------------------------------------------------------------------------
void avrJtagWriteFuseLow(uint8_t);

// ----------------------------------------------------------------------------
// AVR jtag Write the lock byte
// ----------------------------------------------------------------------------
void avrJtagWriteLock(uint8_t);

// ----------------------------------------------------------------------------
// AVR jtag Erase the flash of the chip
// ----------------------------------------------------------------------------
void avrJtagChipErase();


// ----------------------------------------------------------------------------
// AVR jtag Reading the eeprom from addrBegin to addrEnd (addrEnd is included)
// ----------------------------------------------------------------------------
void avrJtagReadEEprom();

// ----------------------------------------------------------------------------
// AVR jtag Writing the eeprom 
// ----------------------------------------------------------------------------
void avrJtagWriteEEprom();

// ----------------------------------------------------------------------------
// AVR jtag Reading the flash
// ----------------------------------------------------------------------------
void avrJtagReadFlash();

// ----------------------------------------------------------------------------
// AVR jtag Writing the flash
// ----------------------------------------------------------------------------
void avrJtagWriteFlash();


#endif
