// ---------------------------------------------------------------------------
// @file       crc.c
// @brief      CRC algorithms
// 
// @author     Laurent Saint-Marcel (lstmarcel@yahoo.fr)
// @date       2009/09/25
// ---------------------------------------------------------------------------

#include "crc.h"

// ---------------------------------------------------------------------------
// Add 'data' to the 8 bits crc computation.
// 'crc' is the previous crc value
// return the new crc value
// ---------------------------------------------------------------------------
unsigned char 
CRC8(unsigned char data, 
     unsigned char crc)
{
    unsigned char i, feedback;

    for (i=0; i<8; i++)
    {
        feedback = ((crc ^ data) & 0x01);
        if (!feedback) {
            crc >>= 1;
        } else {
            crc ^= 0x18;
            crc >>= 1;
            crc |= 0x80;
        }
        data >>= 1;
    }
    return crc;   
}

// ---------------------------------------------------------------------------
// Add 'data' to the 8 bits crc computation.
// 'crc' is the previous crc value
// return the new crc value
// ---------------------------------------------------------------------------
unsigned char
CRC16(unsigned short data, 
      unsigned char crc)
{
    crc = CRC8(data & 0xFF, crc);
    crc = CRC8((data>>8) & 0xFF, crc);
    return crc;
} 

// ---------------------------------------------------------------------------
// Add 'data' to the 8 bits crc computation.
// 'crc' is the previous crc value
// return the new crc value
// ---------------------------------------------------------------------------
unsigned char
CRC32(unsigned long data, 
      unsigned char crc)
{
    crc = CRC8(data & 0xFF, crc);
    crc = CRC8((data>>8)  & 0xFF, crc);
    crc = CRC8((data>>16) & 0xFF, crc);
    crc = CRC8((data>>24) & 0xFF, crc);
    return crc;
} 
