// ---------------------------------------------------------------------------
// @file       jtag.h
// @brief      JTAG basic commands
// 
// @author     Laurent Saint-Marcel (lstmarcel@yahoo.fr)
// @date       2009/09/25
// ---------------------------------------------------------------------------


#ifndef __JTAG__H__
#define __JTAG__H__

// ---------------------------------------------------------------------------
// Configure the IO ports of the atmel
// ---------------------------------------------------------------------------
void jtagInit();

// ---------------------------------------------------------------------------
// Set the Jtag reset pin state
// ---------------------------------------------------------------------------
void jtagReset(unsigned char reset);

// ---------------------------------------------------------------------------
// set the JTAG in the idle state
// ---------------------------------------------------------------------------
void jtagTestLogicReset();

// ---------------------------------------------------------------------------
// set the JTAG in the Shift IR state
// prerequisit, we must be in the TestLogicReset state or RunTestIdle
// ---------------------------------------------------------------------------
void jtagShiftIR();

// ---------------------------------------------------------------------------
// set the JTAG in the Shift DR state
// prerequisit, we must be in the TestLogicReset state or RunTestIdle
// ---------------------------------------------------------------------------
void jtagShiftDR();

// ---------------------------------------------------------------------------
// set the JTAG in the Run Test Idle State when the jtag is in Shift IR or ShiftDR
// prerequisit, we must be in the Shift DR state or Shift IR state 
// ---------------------------------------------------------------------------
void jtagRunTestIdle();

// ---------------------------------------------------------------------------
// write four bits in the IR register 
// prerequisit, we must be in the Shift IR state
// go in the Exit1-IR State at the end of the function
// ---------------------------------------------------------------------------
void jtagWriteIR(unsigned char data);

// ---------------------------------------------------------------------------
// write 'length' bits in the IR register 
// prerequisit, we must be in the Shift DR state
// if exitAtLast != 0, go in the Exit1-DR State after writting the last bit
// if exitAtLast = 0, stay in the Shift DR State after writting the last bit
// ---------------------------------------------------------------------------
unsigned char jtagWriteDR(unsigned char data, 
                          unsigned char length,
                          unsigned char exitAtLast);

// ---------------------------------------------------------------------------
// JTAG IR codes 
// ---------------------------------------------------------------------------

#define JTAG_EXTEST         0x0
#define JTAG_IDCODE         0x1
#define JTAG_BYPASS         0xF
#define JTAG_SAMPLE_PRELOAD 0x2
#define JTAG_AVR_RESET      0xC
#define JTAG_PROG_ENABLE    0x4
#define JTAG_PROG_COMMANDS  0x5
#define JTAG_PROG_PAGELOAD  0x6
#define JTAG_PROG_PAGEREAD  0x7

#endif
