/**
 * @file       larvorProtocol.h
 * @brief      communication protocol between the Larvor board and the PC
 * 
 * @author     Laurent Saint-Marcel (lstmarcel@yahoo.fr)
 * @date       2009/09/25
 */

#ifndef __LARVOR_PROTOCOL_H__
#define __LARVOR_PROTOCOL_H__

// BASIC commands
#define PROG_PING                        0x01   // IN: - OUT: [PROG_PING]

#define PROG_SPECIAL_CHAR                0x02   // Not a command : 0x02
#define PROG_OK                          0x03   // Not a command :
#define PROG_CRC_OK                      0x04   // Not a command :
#define PROG_CRC_ERROR                   0x05   // Not a command :
#define PROG_ERROR                       0x06   // Not a command
#define PROG_CANCEL                      0x07   // Not a command
#define PROG_TIMEOUT                     0x08   // Not a command
#define PROG_SYNC1                       0x0E   // Not a command
#define PROG_SYNC2                       0x0F   // Not a command

// leds
#define PROG_SET_LED_1                   0x10   // IN: [8bits_led_red_mask]  - OUT: 
#define PROG_SET_LED_2                   0x11   // IN: [8bits_led_blue_mask] - OUT:

// JTAG Avr commands
#define PROG_JTAG_GET_DEVICE_ID          0x20   // IN: - OUT: [4 bytes signature] [PROG_OK]
#define PROG_JTAG_READ_SIGNATURE         0x21   // IN: - OUT: [signa1] [signa2] [signa3][0x00] [PROG_OK]
#define PROG_JTAG_READ_CALIBRATION       0x22   // IN: - OUT: [calibration] [PROG_OK]
#define PROG_JTAG_READ_FUSE_EXT          0x23   // IN: - OUT: [fuse_ext] [PROG_OK]
#define PROG_JTAG_READ_FUSE_HIGH         0x24   // IN: - OUT: [fuse_high] [PROG_OK]
#define PROG_JTAG_READ_FUSE_LOW          0x25   // IN: - OUT: [fuse_low] [PROG_OK]
#define PROG_JTAG_READ_LOCK              0x26   // IN: - OUT: [lock] [PROG_OK]
#define PROG_JTAG_WRITE_FUSE_EXT         0x27   // IN: [fuse_ext][CRC8]  - OUT: [PROG_OK] / [PROG_ERROR]
#define PROG_JTAG_WRITE_FUSE_HIGH        0x28   // IN: [fuse_high][CRC8] - OUT: [PROG_OK] / [PROG_ERROR]
#define PROG_JTAG_WRITE_FUSE_LOW         0x29   // IN: [fuse_low][CRC8]  - OUT: [PROG_OK] / [PROG_ERROR]
#define PROG_JTAG_WRITE_LOCK             0x2A   // IN: [lock][CRC8]      - OUT: [PROG_OK] / [PROG_ERROR]
#define PROG_JTAG_CHIP_ERASE             0x2B   // IN: - OUT: [PROG_OK]
#define PROG_JTAG_READ_EEPROM            0x2C   // IN: [addrBeginL] [addrBeginH] [addrEndL] [addrEndH] [CRC8] - OUT: [one byte per data] [...] [PROG_OK]
#define PROG_JTAG_WRITE_EEPROM           0x2D   // IN: [addrBeginL] [addrBeginH] [addrEndL] [addrEndH] [CRC8] [one byte per data] [...] - OUT: [PROG_OK]
#define PROG_JTAG_READ_FLASH             0x2E   // IN: [addrBeginL] [addrBeginH] [addrEndL] [addrEndH] [CRC8] - OUT: [dataL][dataH] [...] [PROG_OK]
#define PROG_JTAG_WRITE_FLASH            0x2F   // IN: [addrBeginL] [addrBeginH] [addrEndL] [addrEndH] [CRC8] [dataL][dataH] [...] - OUT:  [PROG_OK]

// SPI commands
#define PROG_SPI_GET_DEVICE_ID          0xA0   // IN: - OUT: [4 bytes signature] [PROG_OK]
#define PROG_SPI_READ_SIGNATURE         0xA1   // IN: - OUT: [signa1] [signa2] [signa3] [PROG_OK]
#define PROG_SPI_READ_CALIBRATION       0xA2   // IN: - OUT: [calibration] [PROG_OK]
#define PROG_SPI_READ_FUSE_EXT          0xA3   // IN: - OUT: [fuse_ext] [PROG_OK]
#define PROG_SPI_READ_FUSE_HIGH         0xA4   // IN: - OUT: [fuse_high] [PROG_OK]
#define PROG_SPI_READ_FUSE_LOW          0xA5   // IN: - OUT: [fuse_low] [PROG_OK]
#define PROG_SPI_READ_LOCK              0xA6   // IN: - OUT: [lock] [PROG_OK]
#define PROG_SPI_WRITE_FUSE_EXT         0xA7   // IN: [fuse_ext]  - OUT: [PROG_OK]
#define PROG_SPI_WRITE_FUSE_HIGH        0xA8   // IN: [fuse_high] - OUT: [PROG_OK]
#define PROG_SPI_WRITE_FUSE_LOW         0xA9   // IN: [fuse_low]  - OUT: [PROG_OK]
#define PROG_SPI_WRITE_LOCK             0xAA   // IN: [lock]      - OUT: [PROG_OK]
#define PROG_SPI_CHIP_ERASE             0xAB   // IN: - OUT: [PROG_OK]
#define PROG_SPI_READ_EEPROM            0xAC   // IN: [addrBeginL] [addrBeginH] [addrEndL] [addrEndH] - OUT: [one byte per data] [...] [PROG_OK]
#define PROG_SPI_WRITE_EEPROM           0xAD   // IN: [addrBeginL] [addrBeginH] [addrEndL] [addrEndH] [one byte per data] [...] - OUT: [PROG_OK]
#define PROG_SPI_READ_FLASH             0xAE   // IN: [addrBeginL] [addrBeginH] [addrEndL] [addrEndH] - OUT: [dataL][dataH] [...] [PROG_OK]
#define PROG_SPI_WRITE_FLASH            0xAF   // IN: [addrBeginL] [addrBeginH] [addrEndL] [addrEndH] [dataL][dataH] [...] - OUT:  [PROG_OK]


#define PROG_CRC_CHECK_SIZE             16 // send the CRC every 16 bytes
#endif
