/**
 * @file       spi.c
 * @brief      SPI communication for AVR 
 * 
 * @author     Laurent Saint-Marcel (lstmarcel@yahoo.fr)
 * @date       2009/09/25
 */

#ifndef __SPI__H__
#define __SPI__H__

// ----------------------------------------------------------------------------
// Initialize the SPI port
// ----------------------------------------------------------------------------
void spiInit();

// ----------------------------------------------------------------------------
// AVR spi Reading signature
// ----------------------------------------------------------------------------
uint32_t spiReadSignature();
// ----------------------------------------------------------------------------
// AVR spi Reading deviceId
// Use spiReadSignature to emulate te jtag function avrJtagGetDeviceId
// ----------------------------------------------------------------------------
uint32_t spiGetDeviceId();
// ----------------------------------------------------------------------------
// AVR spi Reading calibration byte
// ----------------------------------------------------------------------------
uint8_t spiReadCalibration();
// ----------------------------------------------------------------------------
// AVR spi Reading the Fuse High byte
// ----------------------------------------------------------------------------
uint8_t spiReadFuseExt();
// ----------------------------------------------------------------------------
// AVR spi Reading the Fuse High byte
// ----------------------------------------------------------------------------
uint8_t spiReadFuseHigh();
// ----------------------------------------------------------------------------
// AVR spi Reading the Fuse Low byte
// ----------------------------------------------------------------------------
uint8_t  spiReadFuseLow();
// ----------------------------------------------------------------------------
// AVR spi Reading the Lock byte
// ----------------------------------------------------------------------------
uint8_t spiReadLock();

// ----------------------------------------------------------------------------
// AVR spi Writing the Fuse Extended byte
// ----------------------------------------------------------------------------
void spiWriteFuseExt(uint8_t data);
// ----------------------------------------------------------------------------
// AVR spi Writing the Fuse High byte
// ----------------------------------------------------------------------------
void spiWriteFuseHigh(uint8_t data);
// ----------------------------------------------------------------------------
// AVR spi Writing the Fuse Low bytes
// ----------------------------------------------------------------------------
void spiWriteFuseLow(uint8_t data);
// ----------------------------------------------------------------------------
// AVR jtag Writing the Lock bytes
// ----------------------------------------------------------------------------
void spiWriteLock(uint8_t data);

// ----------------------------------------------------------------------------
// AVR spi Reading the eeprom from addrBegin to addrEnd (addrEnd is included)
// ----------------------------------------------------------------------------
void spiReadEEprom();
// ----------------------------------------------------------------------------
// AVR spi Writing the eeprom 
// ----------------------------------------------------------------------------
void spiWriteEEprom();

// ----------------------------------------------------------------------------
// AVR spi Reading the flash
// ----------------------------------------------------------------------------
void spiReadFlash();
// ----------------------------------------------------------------------------
// AVR spi Writing the flash
// ----------------------------------------------------------------------------
void spiWriteFlash();

// ----------------------------------------------------------------------------
// erase the flash and eeprom
// ----------------------------------------------------------------------------
void spiChipErase();



#endif
