/**
 * @file       time.c
 * @brief      time driver
 * 
 * @author     Laurent Saint-Marcel (lstmarcel@yahoo.fr)
 * @date       2010/07/13
 */

#include <avr/io.h>
#include <avr/interrupt.h>
#include "time.h"
#include "util.h"

/* ------------------------------------------------------------------------ */
/* static                                                                   */
/* ------------------------------------------------------------------------ */
static struct {
    uint32_t  dateTimer_;
} TIME;

/* ------------------------------------------------------------------------ */
/* ISR(SIG_OVERFLOW1)                                                       */
/* ------------------------------------------------------------------------ */
/* Interrupt when Timer 1 reached overflow                                  */
/* ------------------------------------------------------------------------ */
ISR(SIG_OVERFLOW2)  
{
    // every 8.192 ms
	++TIME.dateTimer_;
	TCNT2 = 121;
}

/* ------------------------------------------------------------------------ */
/* timeInit                                                                */
/* ------------------------------------------------------------------------ */
void timeInit()
{
    timeReset();

    /* Set timer 0 speed : CLK/64 = 0.032ms/tick */
    TCCR2 = 0x04;
    /* Set timer 0 value, when reach overflow, INTERRUPT(SIG_OVERFLOW1) is run */
    TCNT2 = 121;
    /* Enable timer 0 interrupt */
    sbi(TIMSK, TOIE2);
}

/* ------------------------------------------------------------------------ */
/* timeReset                                                                */
/* ------------------------------------------------------------------------ */
void timeReset()
{
	TIME.dateTimer_ = 0;
}

/* ------------------------------------------------------------------------ */
/* timeGet                                                                  */
/* ------------------------------------------------------------------------ */
/* return the time in ms                                                    */
/* ------------------------------------------------------------------------ */
uint32_t timeGet()
{ 
	return TIME.dateTimer_;
}
